******
djohno
******

djohno is a tiny app for checking over your error pages, and email
integration - to stop me doing evil things post-production to ensure
I've set up Sentry and my error pages by randomly breaking parts of my
site by editing code live.

Release Notes
=============

0.1.1 (TBC)
-----------

* Fix the email address the test email is sent from, add checking that
  it's a valid email address, and encourage users to set
  `DEFAULT_FROM_EMAIL` to a friendly address (`Your Name
  <you@yourcompany.com>`);
* Ensure setup.py has a short and a long description;
* Improved documentation.

0.1.0 (27th June 2013)
----------------------

* Initial release
